@@ -10,17 +10,13 @@ TZ = pytz.timezone("Europe/Oslo")
 
 
 class FloatEnum(float, Enum):
-    """
-    Enum where members are also (and must be) floats
-    """
+    """Enum where members are also (and must be) floats. (Copied from Enum source.)"""
 
     def __str__(self):
         return "%s" % (self._name_,)
 
     def __format__(self, format_spec):
-        """
-        Returns format using actual value unless __str__ has been overridden.
-        """
+        """Returns format using actual value unless __str__ has been overridden."""
         str_overridden = type(self).__str__ != FloatEnum.__str__
         if str_overridden:
             cls = str
